//+------------------------------------------------------------------+
//|                                        position_reversal_v1.mq5  |
//|                        Copyright 2016, MetaQuotes Software Corp. |
//|                                             https://www.mql5.com |
//+------------------------------------------------------------------+
#property copyright "Copyright 2016, MetaQuotes Software Corp."
#property link      "https://www.mql5.com"
#property version   "1.00"
#property description "Reverse position and study \"DEAL_POSITION_ID\" history deals. Profit positions"
#property script_show_inputs
//--- input
input datetime start=D'2016.08.05 09:00:00';
//---
#include <Trade\Trade.mqh>
//--- variable
CTrade   my_trade;            // object CTrade
//+------------------------------------------------------------------+
//| Script program start function                                    |
//+------------------------------------------------------------------+
int OnStart()
  {
//---
   if(AccountInfoInteger(ACCOUNT_MARGIN_MODE)==ACCOUNT_MARGIN_MODE_RETAIL_HEDGING)
     {
      Print("This script cannot be run on a hedge");
      return(INIT_FAILED);
     }
//--- the trading bloc 1
   Print("trading bloc 1: Buy 0.01, \"EURUSD\"");
   my_trade.Buy(0.01,"EURUSD");
   Sleep(600);
   Print_IDs();
   Sleep(60000*3);            // sleep 3 minutes

//--- the trading bloc 2
   Print("trading bloc 2: Sell 0.02, \"EURUSD\"");
   my_trade.Sell(0.02,"EURUSD");
   Sleep(600);
   Print_IDs();
   Sleep(60000*3);            // sleep 3 minutes

//--- the trading bloc 3
   Print("trading bloc 3: PositionClose, \"EURUSD\"");
   my_trade.PositionClose("EURUSD");
   Sleep(600);
   Print_IDs();
   PrintProfitPositions();

//--- succeed
   return(INIT_SUCCEEDED);
  }
//+------------------------------------------------------------------+
//| List all positions and deals                                     |
//+------------------------------------------------------------------+
void Print_IDs(void)
  {
   for(int i=0;i<PositionsTotal();i++)
     {
      //--- 
      string pos_symbol=PositionGetSymbol((uint)i);
      if(pos_symbol!=NULL)
        {
         //--- 
         ulong position_ID=PositionGetInteger(POSITION_IDENTIFIER);
         Print("Position ",pos_symbol," POSITION_IDENTIFIER #",position_ID);
        }
     }
//--- request trade history 
   HistorySelect(start,TimeCurrent());
   uint     total    =HistoryDealsTotal();
   ulong    ticket   =0;
   long     deal_id  =0;
   double   volume   =0.0;
   double   profit   =0.0;
   string   symbol   =NULL;
//--- for all deals 
   for(uint i=0;i<total;i++)
     {
      //--- try to get deals ticket 
      if((ticket=HistoryDealGetTicket(i))>0)
        {
         //--- get deals properties 
         deal_id  =HistoryDealGetInteger(ticket,DEAL_POSITION_ID);
         volume   =HistoryDealGetDouble(ticket,DEAL_VOLUME);
         profit   =HistoryDealGetDouble(ticket,DEAL_PROFIT);
         symbol   =HistoryDealGetString(ticket,DEAL_SYMBOL);
         Print("Deal ",symbol," volume ",DoubleToString(volume,2),
               " DEAL_POSITION_ID #",deal_id," profit ",DoubleToString(profit,2));
        }
     }
   Print("");
  }
//+------------------------------------------------------------------+
//| Print ptofit positions                                           |
//+------------------------------------------------------------------+
void PrintProfitPositions(void)
  {
//--- structure profit positions;
   struct struct_positions
     {
      long              id;
      double            profit;
      //--- constructor
                        struct_positions() {id=0; profit=0.0;}
     };
   struct_positions arr_struct_positions[];
//--- request trade history 
   HistorySelect(start,TimeCurrent());
   uint     total    =HistoryDealsTotal();
   ulong    ticket   =0;
   long     deal_id  =0;
   double   profit   =0;
   long     type     =0;
//--- for all deals 
   for(uint i=0;i<total;i++)
     {
      //--- try to get deals ticket 
      if((ticket=HistoryDealGetTicket(i))>0)
        {
         //--- get deals properties 
         deal_id  =HistoryDealGetInteger(ticket,DEAL_POSITION_ID);
         profit   =HistoryDealGetDouble(ticket,DEAL_PROFIT);
         type     =HistoryDealGetInteger(ticket,DEAL_TYPE);
         //--- only buy or sell;  buy  sell
         if(type==DEAL_TYPE_BUY || type==DEAL_TYPE_SELL)
           {
            bool seach=false;
            int number=ArraySize(arr_struct_positions);
            for(int j=0;j<number;j++)
              {
               if(arr_struct_positions[j].id==deal_id)
                 {
                  arr_struct_positions[j].profit+=profit;
                  seach=true;
                  break;
                 }
              }
            if(!seach)
              {
               ArrayResize(arr_struct_positions,number+1);
               arr_struct_positions[number].id=deal_id;
               arr_struct_positions[number].profit+=profit;
              }
           }
        }
     }
//---
   int number=ArraySize(arr_struct_positions);
   for(int i=0;i<number;i++)
     {
      Print("id ",arr_struct_positions[i].id," profit ",arr_struct_positions[i].profit);
     }
  }
//+------------------------------------------------------------------+
